==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core/lumina-info/i18n/lumina-info_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Lumina Desktop Information</source>
        <translation>Informacje pulpitu Lumina</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="60"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Source Repository</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Lumina Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Bug Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="179"/>
        <source>Desktop Version:</source>
        <translation>Wersja pulpitu:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="202"/>
        <source>OS Build:</source>
        <translation>Wersja systemu operacyjnego:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Qt Version:</source>
        <translation>Wersja Qt:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="276"/>
        <source>Ask the Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="233"/>
        <source>View Information</source>
        <translation>Wyświetl informacje</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="315"/>
        <source>Acknowledgements</source>
        <translation>Podziękowania</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="333"/>
        <source>Project Lead:</source>
        <translation>Lider projektu:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="353"/>
        <source>Contributors:</source>
        <translation>Współtwórcy:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="366"/>
        <source>Sponsors:</source>
        <translation>Sponsorzy:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Open in web browser&lt;a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Otwórz w przeglądarce internetowej&lt;a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="454"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/core/lumina-info/i18n/lumina-info_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Lumina Desktop Information</source>
        <translation>Informacje pulpitu Lumina</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="60"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Source Repository</source>
        <translation>Repozytorium Żródłowe</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Lumina Website</source>
        <translation>Strona WWW Lumina</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Bug Reports</source>
        <translation>Zgłaszanie Błędów</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="179"/>
        <source>Desktop Version:</source>
        <translation>Wersja pulpitu:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="202"/>
        <source>OS Build:</source>
        <translation>Wersja systemu operacyjnego:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Qt Version:</source>
        <translation>Wersja Qt:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="276"/>
        <source>Ask the Community</source>
        <translation type="unfinished">Zadaj Pytanie</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="233"/>
        <source>View Information</source>
        <translation>Wyświetl informacje</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="315"/>
        <source>Acknowledgements</source>
        <translation>Podziękowania</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="333"/>
        <source>Project Lead:</source>
        <translation>Lider projektu:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="353"/>
        <source>Contributors:</source>
        <translation>Współtwórcy:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="366"/>
        <source>Sponsors:</source>
        <translation>Sponsorzy:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Open in web browser&lt;a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Otwórz w przeglądarce internetowej&lt;a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="454"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
</TS>
